==> jcodemodel-2.7.3-sources.jar: com/helger/jcodemodel/fmt/JSerializedObject.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.helger.jcodemodel.fmt;

import java.io.IOException;
import java.io.ObjectOutputStream;
import java.io.OutputStream;

import javax.annotation.Nonnull;

import com.helger.jcodemodel.AbstractJResourceFile;

/**
 * A simple class that takes an object and serializes it into a file in the
 * parent package with the given name.
 */
public class JSerializedObject extends AbstractJResourceFile
{
  private final Object _obj;

  /**
   * @exception IOException
   *            If the serialization fails, this exception is thrown
   */
  public JSerializedObject (@Nonnull final String name, @Nonnull final Object obj) throws IOException
  {
    super (name);
    this._obj = obj;
  }

  /**
   * called by JPackage to serialize the object
   */
  @Override
  protected void build (@Nonnull final OutputStream os) throws IOException
  {
    // serialize the obj into a ByteArrayOutputStream
    final ObjectOutputStream oos = new ObjectOutputStream (os);
    oos.writeObject (_obj);
    oos.close ();
  }
}

==> jcodemodel-2.8.6-sources.jar: com/helger/jcodemodel/fmt/JSerializedObject.java <==
/**
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 * Portions Copyright 2013-2016 Philip Helger + contributors
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.helger.jcodemodel.fmt;

import java.io.IOException;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.io.Serializable;

import javax.annotation.Nonnull;

import com.helger.jcodemodel.AbstractJResourceFile;

/**
 * A simple class that takes an object and serializes it into a file in the
 * parent package with the given name.
 */
public class JSerializedObject extends AbstractJResourceFile
{
  private final Serializable m_aObj;

  /**
   * @param name
   *        Name
   * @param obj
   *        Serializable object
   * @throws IOException
   *         If the serialization fails, this exception is thrown
   */
  public JSerializedObject (@Nonnull final String name, @Nonnull final Serializable obj) throws IOException
  {
    super (name);
    m_aObj = obj;
  }

  @Override
  protected void build (@Nonnull final OutputStream os) throws IOException
  {
    // serialize the obj into a ByteArrayOutputStream
    final ObjectOutputStream oos = new ObjectOutputStream (os);
    oos.writeObject (m_aObj);
    oos.close ();
  }
}
